@@ -1,5 +1,5 @@
 from .serverlistenable import TCPServer
 from .socketutils import ServerSocket, ClientSocket, TCPSocket
-from .protocols import Protocol_HTTP, HTTPIncoming, HTTPOutgoing
+from .protocols import Protocol_HTTP, HTTPIncoming, HTTPOutgoing, HFE, Protocol_WebSockets
 from .server import *
 from .extensions import *
